OpenWakeWordBindings class
Bindings for open_wake_word
Constructors
- OpenWakeWordBindings(DynamicLibrary dynamicLibrary)
-
The symbols are looked up in
dynamicLibrary. -
OpenWakeWordBindings.fromLookup(Pointer<
T> lookup<T extends NativeType>(String symbolName) ) -
The symbols are looked up with
lookup.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
oww_destroy(
) → void -
oww_get_probability(
) → double -
oww_init(
Pointer< Char> mel_model_path, Pointer<Char> emb_model_path, Pointer<Char> ww_model_path) → int -
oww_is_activated(
) → bool -
oww_process_audio(
Pointer< Int16> audio_data, int length) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited